@@ -20,7 +20,7 @@ def lines2unicode(lines=[], strip=False, sep=u"\n"):
     """
     if strip:
         return reduce(lambda a, b: a.strip() + sep + b.strip(), lines, u"").strip()
-    return reduce(lambda a, b: a + sep + b, lines, u"")
+    return reduce(lambda a, b: a + sep + b, lines, u"")[1:]
 
 def is_empty(lines):
     """Checks whether a list of ustrings is empty.
@@ -106,24 +106,34 @@ def avg_words_per_line(lines):
 
 
 if __name__ == '__main__':
-    """lines.py test"""
+    print "Test for " + __file__
+
     l0 = []
+    l0_expected = u""
     l1 = [u"Hello World!"]
+    l1_expected = u"Hello World!"
     l2 = [u"Hello World,", u"how are you?", u"Sincerely", u"Universe"]
+    l2_expected = u"Hello World,\nhow are you?\nSincerely\nUniverse"
     l3 = [u"    ", u"\n", u""]
 
-    print lines2unicode(l0)
-    print lines2unicode(l1)
-    print lines2unicode(l2)
+    assert lines2unicode(l0) == l0_expected
+    assert lines2unicode(l1) == l1_expected
+    assert lines2unicode(l2) == l2_expected
 
     assert is_empty(l0)
     assert is_empty(l3)
     assert not is_empty(l1)
     assert not is_empty(l2)
 
-    h0 = [u"     42", u" The Meaning of Life and Everything"]
-    assert match(r"\d+", h0, True)
-    print lines2unicode(h0, True)
+    headline = [u"     42", u" The Meaning of Life and Everything"]
+    headline_expected = u"42\nThe Meaning of Life and Everything"
+    assert match(r"\d+", headline, True)
+    assert lines2unicode(headline, True) == headline_expected
 
     l4 = [u"x     2  ", u"  yz xz"]
     assert avg_word_length(l4) == 1.5
+
+    # avg_words_per_line
+    assert avg_words_per_line(l0) == 0.0
+    assert avg_words_per_line(l2) == 1.75
+    assert avg_words_per_line(l4) == 2.0
